pub async fn collect_response<S>(
stream: S,
) -> Result<AssistantResponse, LlmError>Expand description
Collect a chat stream into a single assistant response.
pub async fn collect_response<S>(
stream: S,
) -> Result<AssistantResponse, LlmError>Collect a chat stream into a single assistant response.